
REST API for Django CMS Based on Django REST Framework
======================================================

Build status
------------

.. image:: https://travis-ci.org/inonit/djangocms-restapi.svg
    :target: https://travis-ci.org/inonit/djangocms-restapi
    :alt: Build status

.. image:: https://readthedocs.org/projects/drf-haystack/badge/?version=latest
    :target: http://djangocms-restapi.readthedocs.org/en/latest/
    :alt: Documentation Status
    

Installation
============

Not yet released


Contribution
============

Yes, please =)
